@@ -13,14 +13,13 @@ class OidcClientManager:
     client = None
 
     @classmethod
-    def get_client_for_callback_url(cls, callback_url):
+    def get_client(cls):
         if cls.client:
             return cls.client
 
         configuration = retrieve()
         client_credentials = register({
             'token_endpoint_auth_method': 'none',
-            'redirect_uris': [callback_url],
             'registration_endpoint': configuration['registration_endpoint']
         })
         logger.debug(f"client_credentials: {client_credentials}")
@@ -31,14 +30,14 @@ class OidcClientManager:
 
         op_info = ProviderConfigurationResponse(
             client_id=client_data['client_id'],
-            redirect_uri=callback_url,
+            redirect_uri=client_credentials['redirect_uris'][0],
             issuer=client_data['issuer'],
             authorization_endpoint=urljoin(client_data['issuer'], 'oidc/auth'),
             token_endpoint=urljoin(client_data['issuer'], 'oidc/token'),
             jwks_uri=urljoin(client_data['issuer'], 'oidc/jwks')
         )
-
         cls.client = Client(client_data['client_id'], verify_ssl=False)
+        cls.client.redirect_uris = client_credentials['redirect_uris']
         cls.client.handle_provider_config(op_info, op_info['issuer'])
 
         return cls.client
